@@ -14,9 +14,13 @@ import (
 	"github.com/idursun/jjui/internal/ui/operations"
 )
 
+var _ operations.Operation = (*Operation)(nil)
+var _ common.Focusable = (*Operation)(nil)
+
 type Operation struct {
 	context     *context.MainContext
 	from        jj.SelectedRevisions
+	files       []string
 	current     *jj.Commit
 	keyMap      config.KeyMappings[key.Binding]
 	keepEmptied bool
@@ -24,16 +28,36 @@ type Operation struct {
 	styles      styles
 }
 
+func (s *Operation) IsFocused() bool {
+	return true
+}
+
 type styles struct {
 	dimmed       lipgloss.Style
 	sourceMarker lipgloss.Style
 	targetMarker lipgloss.Style
 }
 
+func (s *Operation) Init() tea.Cmd {
+	return nil
+}
+
+func (s *Operation) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
+	if msg, ok := msg.(tea.KeyMsg); ok {
+		return s, s.HandleKey(msg)
+	}
+	return s, nil
+}
+
+func (s *Operation) View() string {
+	return ""
+}
+
 func (s *Operation) HandleKey(msg tea.KeyMsg) tea.Cmd {
 	switch {
-	case key.Matches(msg, s.keyMap.Apply):
-		return tea.Batch(common.Close, s.context.RunInteractiveCommand(jj.Squash(s.from, s.current.GetChangeId(), s.keepEmptied, s.interactive), common.RefreshAndSelect(s.current.GetChangeId())))
+	case key.Matches(msg, s.keyMap.Apply, s.keyMap.ForceApply):
+		ignoreImmutable := key.Matches(msg, s.keyMap.ForceApply)
+		return tea.Batch(common.Close, s.context.RunInteractiveCommand(jj.Squash(s.from, s.current.GetChangeId(), s.files, s.keepEmptied, s.interactive, ignoreImmutable), common.RefreshAndSelect(s.current.GetChangeId())))
 	case key.Matches(msg, s.keyMap.Cancel):
 		return common.Close
 	case key.Matches(msg, s.keyMap.Squash.KeepEmptied):
@@ -88,16 +112,28 @@ func (s *Operation) FullHelp() [][]key.Binding {
 	return [][]key.Binding{s.ShortHelp()}
 }
 
-func NewOperation(context *context.MainContext, from jj.SelectedRevisions) *Operation {
+type Option func(*Operation)
+
+func WithFiles(files []string) Option {
+	return func(op *Operation) {
+		op.files = files
+	}
+}
+
+func NewOperation(context *context.MainContext, from jj.SelectedRevisions, opts ...Option) *Operation {
 	styles := styles{
 		dimmed:       common.DefaultPalette.Get("squash dimmed"),
 		sourceMarker: common.DefaultPalette.Get("squash source_marker"),
 		targetMarker: common.DefaultPalette.Get("squash target_marker"),
 	}
-	return &Operation{
+	o := &Operation{
 		context: context,
 		keyMap:  config.Current.GetKeyMap(),
 		from:    from,
 		styles:  styles,
 	}
+	for _, opt := range opts {
+		opt(o)
+	}
+	return o
 }
